[![CI](https://github.com/CAB-Lab-Princeton/hgan/actions/workflows/main.yml/badge.svg)](https://github.com/CAB-Lab-Princeton/hgan/actions/workflows/main.yml)
# hGAN: Interpretable dynamics from images of a mechanical system

A work in progress ...

## Documentation

The latest version of hgan documentation is available [here](https://CAB-Lab-Princeton.github.io/hgan/).
